ensure_custom_data_registered

Function ensure_custom_data_registered 

pub fn ensure_custom_data_registered<T>()
where T: CustomDataTrait + ArrowSchemaProvider + EncodeToRecordBatch + DecodeDataFromRecordBatch + Clone + Send + Sync + 'static,
Registers a custom data type in the JSON and Arrow registries. Call once per type (e.g. at catalog decode or before querying custom data).

Each distinct type T is registered at most once (per process). Safe to call multiple times for the same T.

For types exposed to Python, also call [nautilus_model::data::register_rust_extractor::<T>()].